import {BasicColumn, FormSchema} from "@/components/Table";
import {uploadApi} from "@/api/sys/upload";
import {DescItem} from "@/components/Description";

// 搜索栏参数
export const searchFormSchema: FormSchema[] = [
  {
    field: 'connectName',
    component: 'Input',
    componentProps: {
      placeholder: '输入关键字搜索',
    },
    colProps: {span: 7},
  },
];

// 表头列表头
export const columns: BasicColumn[any] = [
  {
    title: '连接名称',
    dataIndex: 'connectName',
    width: 150,
  },
  {
    title: '连接字符串',
    dataIndex: 'connectString',
    width: 150,
  },
  {
    title: '连接类型',
    dataIndex: 'connectType',
    width: 150,
  },
  {
    title: '认证状态',
    dataIndex: 'authStatus',
    width: 150,
  },
  {
    title: '已创建数据源',
    dataIndex: 'foundDataSource',
    width: 150,
  },
  {
    title: '执行状态',
    dataIndex: 'executionState',
    width: 150,
  },
  {
    title: '采集类型',
    dataIndex: 'collectionType',
    width: 150,
  },
  {
    title: '最近采集时间',
    dataIndex: 'updateDate',
    width: 150,
  },
];

// 表单表头
export const formSchema: FormSchema[any] = [
  {
    field: 'connectName',
    label: '连接名称',
    component: 'Input',
    required: true,
    // disabled: ({ mergeDynamicData }) => mergeDynamicData.idDisabled,
  },
  {
    field: 'connectType',
    label: '连接类型',
    component: 'Select',
    required: true,
    componentProps: {
      options: [
        {label: 'Inceptor', value: '0'},
        {label: 'Teradata', value: '1'},
        {label: 'ArgoDB', value: '2'},
        {label: 'Mysql', value: '3'},
        {label: 'Oracle', value: '4'},
        {label: 'HDFS', value: '5'},
        {label: 'Hbase', value: '6'},
        {label: 'Hyperbase', value: '7'},
        {label: 'Impala', value: '8'},
        {label: 'DB2', value: '9'},
        {label: 'SQLServer', value: '10'},
        {label: 'Hive', value: '11'},
        {label: 'KunDB', value: '12'},
        {label: '达梦', value: '13'},
        {label: 'HANA', value: '14'},
        {label: 'Postgres', value: '15'},
        {label: 'FTP', value: '16'},
        {label: 'SFTP', value: '17'},
        {label: 'Kingbase', value: '18'},
        {label: 'Gbase', value: '19'},
        {label: 'Greenplum', value: '20'},
        {label: 'Trino', value: '21'},
        {label: 'MongoDB', value: '22'},
        {label: 'OceanBase', value: '23'},
        {label: 'AS400', value: '23'},
        {label: '自定义', value: '24'},
        {label: 'Kafka', value: '25'},
        {label: 'Clickhouse', value: '26'},
        {label: 'S3', value: '27'},
        {label: 'Timelyre', value: '28'},
      ],
      defaultValue: '0',
    },
  },
  {
    field: 'collectionType',
    label: '采集类型',
    component: 'Select',
    required: true,
    componentProps: {
      options: [
        {label: '在线采集', value: '0'},
        {label: '离线采集', value: '1'},
        {label: '不采集', value: '2'},
      ],
      defaultValue: '0',
    },
  },
  {
    field: 'driveVersion',
    label: '驱动版本',
    component: 'Select',
    required: true,
    componentProps: {
      options: [
        {label: 'oracle11', value: 'oracle11'},
        {label: 'mysql8', value: 'mysql8'},
        {label: 'postgresql42', value: 'postgresql42'},
        {label: 'sqlserver4', value: 'sqlserver4'},
        {label: 'sqlite3', value: 'sqlite3'},
        {label: 'hive', value: 'hive'},
        {label: 'mongodb', value: 'mongodb'},
        {label: 'redis', value: 'redis'},
        {label: 'elasticsearch', value: 'elasticsearch'},
        {label: 'cassandra', value: 'cassandra'},
        {label: 'derby', value: 'derby'},
        {label: 'neo4j', value: 'neo4j'},
      ],
      defaultValue: 'hive',
    },
  },
  {
    field: 'connectString',
    label: '连接字符串',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: "jdbc:hive2://<ip>:10000/default",
    },
  },
  {
    field: 'isPeriodicCheck',
    label: '周期探活',
    component: 'RadioGroup',
    required: true,
    componentProps: {
      options: [
        {label: '开启', value: '0'},
        {label: '关闭', value: '1'},
      ],
      defaultValue: '0',
    },
  },
  {
    field: 'authMode',
    label: '认证模式',
    component: 'Select',
    required: true,
    componentProps: {
      options: [
        {label: 'None', value: 'None'},
        {label: 'Kerberos', value: 'Kerberos'},
        {label: 'LDAP', value: 'LDAP'},
        {label: 'Access Token', value: 'AccessToken'},
        {label: 'Password', value: 'Password'},
      ],
      defaultValue: 'None',
    },
  },
  {
    field: 'username',
    label: '用户名',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: "请输入用户名",
    },
    ifShow: ({ model }) => model.authMode === 'Password' || model.authMode === 'LDAP',
  },
  {
    field: 'password',
    label: '密码',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: "请输入密码",
    },
    ifShow: ({ model }) => model.authMode === 'Password' || model.authMode === 'LDAP',
  },
  {
    field: 'principal',
    label: 'principal',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: "请输入principal",
    },
    ifShow: ({ model }) => model.authMode === 'Kerberos',
  },
  {
    field: 'KUser',
    label: 'KUser',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: "请输入KUser",
    },
    ifShow: ({ model }) => model.authMode === 'Kerberos',
  },
  {
    field: 'KrbHostFQDN',
    label: 'KrbHostFQDN',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: "Kdc主机域名",
    },
    ifShow: ({ model }) => model.authMode === 'Kerberos',
  },
  {
    field: 'KrbRealm',
    label: 'KrbRealm',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: "Kerberos安全领域",
    },
    ifShow: ({ model }) => model.authMode === 'Kerberos',
  },
  {
    field: 'KrbServiceName',
    label: 'KrbServiceName',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: "请输入KrbServiceName",
    },
    ifShow: ({ model }) => model.authMode === 'Kerberos',
  },
  {
    field: 'Keytab',
    label: 'Keytab',
    component: 'Upload',
    rules: [{ required: true, message: '请选择上传文件' }],
    componentProps: {
      api: uploadApi,
    },
    ifShow: ({ model }) => model.authMode === 'Kerberos',
  },
  {
    field: 'krb5',
    label: 'krb5',
    component: 'Upload',
    rules: [{ required: true, message: '请选择上传文件' }],
    componentProps: {
      api: uploadApi,
    },
    ifShow: ({ model }) => model.authMode === 'Kerberos',
  },
  {
    field: 'AccessToken',
    label: 'AccessToken',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: "请输入AccessToken",
    },
    ifShow: ({ model }) => model.authMode === 'AccessToken',
  },
  {
    field: 'hdfsMap',
    label: 'HDFS映射',
    component: 'Select',
    required: true,
    componentProps: {
      options: [
        {
          label: 'hive',
          value: 'hive'
        },
      ],
    },
  },
]

// 重命名表单
export const resetNameFormSchema: FormSchema[any] = [
  {
    field: 'connectName',
    label: '连接名称',
    component: 'Input',
    required: true,
  },
]

// Kbrt表单
export const kbr5FormSchema: FormSchema[any] = [
  {
    field: 'path',
    label: '默认kbr5文件路径',
    component: 'Input',
    required: true,
    defaultValue: 'krb5.conf',
    componentProps: {
      disabled: true,
    },
    labelWidth: 150,
  },
  {
    field: 'file',
    component: 'Upload',
    label: 'Kbr5文件',
    rules: [{ required: true, message: '请选择上传文件' }],
    componentProps: {
      api: uploadApi,
    },
    labelWidth: 150,
  },
]

// 数据源关联列表头
export const dataRelativeColumns: BasicColumn[any] = [
  {
    title: '数据源ID',
    dataIndex: 'dataSourceId',
    width: 150,
  },
  {
    title: '数据源名称',
    dataIndex: 'dataSourceName',
    width: 150,
  },
  {
    title: '认证类型',
    dataIndex: 'authType',
    width: 150,
  },
  {
    title: '拥有者',
    dataIndex: 'holder',
    width: 150,
  },
  {
    title: '所属工作区',
    dataIndex: 'areaName',
    width: 150,
  },
];

// 日志表单表头
export const recordFormSchema: DescItem[any] = [
  {
    field: 'connectName',
    label: '连接名称',
    component: 'Input',
    colProps: {span: 7},
  },
  {
    field: 'connectType',
    label: '连接类型',
    component: 'Input',
    colProps: {span: 7},
  },
  {
    field: 'connectString',
    label: '连接字符串',
    component: 'Input',
    colProps: {span: 7},
  },
  {
    field: 'driveVersion',
    label: '驱动版本',
    component: 'Input',
    colProps: {span: 7},
  },
  {
    field: 'collectionRate',
    label: '采集频率',
    component: 'Input',
    colProps: {span: 7},
  },
  {
    field: 'createTime',
    label: '创建时间',
    component: 'Input',
    colProps: {span: 7},
  },
  {
    field: 'updateTime',
    label: '最近修改时间',
    component: 'Input',
    colProps: {span: 7},
  },
  {
    field: 'implementor',
    label: '执行人',
    component: 'Input',
    colProps: {span: 7},
  },
  {
    field: 'collectionType',
    label: '采集类型',
    component: 'Input',
    colProps: {span: 7},
  },
]

// 日志列表表头
export const recordTableColumns: BasicColumn[any] = [
  {
    title: '数据库',
    dataIndex: 'dataBase',
    width: 150,
  },
  {
    title: '节点',
    dataIndex: 'node',
    width: 150,
  },
  {
    title: '开始时间',
    dataIndex: 'startTime',
    width: 150,
  },
  {
    title: '结束时间',
    dataIndex: 'endTime',
    width: 150,
  },
  {
    title: '耗时',
    dataIndex: 'consumeTime',
    width: 150,
  },
  {
    title: '采集状态',
    dataIndex: 'collectionStatus',
    width: 150,
  },
  {
    title: '数据库表总数',
    dataIndex: 'dataTableNum',
    width: 150,
  },
  {
    title: '采集表总数',
    dataIndex: 'collectionTableNum',
    width: 150,
  },
  {
    title: '新增表总数',
    dataIndex: 'addTableNum',
    width: 150,
  },
  {
    title: '删除表总数',
    dataIndex: 'deleteTableNum',
    width: 150,
  },
  {
    title: '更新表总数',
    dataIndex: 'updateTableNum',
    width: 150,
  },
  {
    title: '未采集表总数',
    dataIndex: 'noCollectTableNum',
    width: 150,
  },
];

// 执行在线采集表单
export const onlineCollectionFormSchema: FormSchema[any] = [
  {
    field: 'executeStyle',
    component: 'RadioGroup',
    label: '执行方式',
    required: true,
    defaultValue: '1',
    componentProps: {
      options: [
        {
          label: '当前采集范围',
          value: '1',
        },
        {
          label: '自定义采集范围',
          value: '2',
        },
        {
          label: '表采集',
          value: '3',
        },
      ],
    },
  },
]

// 执行离线采集表头
export const offlineExecuteColumns: BasicColumn[any] = [
  {
    title: '数据库名称',
    dataIndex: 'dataBaseName',
    width: 150,
  },
  {
    title: '策略',
    dataIndex: 'strategy',
    width: 150,
  },
];

// 执行离线采集搜索表头
export const offlineExecuteSearchSchema: FormSchema[any] = [
  {
    field: 'dataBaseName',
    label: '',
    component: 'Input',
    colProps: {span: 7},
  },
]

// 查看日志详情表单
export const lookRecordFormSchema: FormSchema[any] = [
  {
    field: 'dataBase',
    label: '数据库',
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    }
  },
  {
    field: 'node',
    label: '节点',
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    }
  },
  {
    field: 'startTime',
    label: '开始时间',
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    }
  },
  {
    field: 'endTime',
    label: '结束时间',
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    }
  },
  {
    field: 'consumeTime',
    label: '耗时',
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    }
  },
  {
    field: 'collectionStatus',
    label: '采集状态',
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    }
  },
  {
    field: 'dataTableNum',
    label: '数据库表总数',
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    }
  },
  {
    field: 'collectionTableNum',
    label: '采集表总数',
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    }
  },
  {
    field: 'addTableNum',
    label: '新增表总数',
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    }
  },
  {
    field: 'deleteTableNum',
    label: '删除表总数',
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    }
  },
  {
    field: 'updateTableNum',
    label: '更新表总数',
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    }
  },
  {
    field: 'noCollectTableNum',
    label: '未采集表总数',
    component: 'Input',
    componentProps: {
      readonly: true,
      disabled: true,
    }
  },
]

//添加数据库表单
export const addDataBaseFormSchema: FormSchema[any] = [
  {
    field: 'dataBaseName',
    label: '数据库',
    component: 'Input',
    required: true,
  },
  {
    field: 'strategy',
    label: '策略',
    component: 'Input',
    required: true,
  },
]
