import { FormSchema } from '@/components/Form';
import { BasicColumn } from '@/components/Table';
import { uploadApi } from '@/api/sys/upload';

// 搜索栏参数
export const searchFormSchema: FormSchema[] = [
  {
    field: 'dataSourceName',
    component: 'Input',
    componentProps: {
      placeholder: '输入关键字搜索',
    },
    colProps: { span: 7 },
  },
];

// 表头参数
export const columns: BasicColumn[any] = [
  {
    title: '数据源名称',
    dataIndex: 'dataSourceName',
    width: 150,
    fixed: 'left',
  },
  {
    title: '连接名称',
    dataIndex: 'connectName',
    width: 150,
    fixed: 'left',
  },
  {
    title: '类型',
    dataIndex: 'connectType',
    width: 150,
  },
  {
    title: '认证状态',
    dataIndex: 'authStatus',
    width: 150,
  },
  {
    title: '数据源ID',
    dataIndex: 'dataSourceID',
    width: 200,
  },
  {
    title: '权属工作组',
    dataIndex: 'workingGroup',
    width: 150,
  },
  {
    title: '拥有者',
    dataIndex: 'createBy',
    width: 150,
  },
  {
    title: '创建时间',
    dataIndex: 'createDate',
    width: 150,
  },
  {
    title: '是否在元数据管理中展示',
    dataIndex: 'isShow',
    width: 180,
  },
];

// 表单表头
export const formSchema: FormSchema[] = [
  {
    field: 'connectType',
    label: '数据源类型',
    component: 'Select',
    required: true,
    componentProps: {
      options: [
        { label: 'Inceptor', value: '0' },
        { label: 'Teradata', value: '1' },
        { label: 'ArgoDB', value: '2' },
        { label: 'Mysql', value: '3' },
        { label: 'Oracle', value: '4' },
        { label: 'HDFS', value: '5' },
        { label: 'Hbase', value: '6' },
        { label: 'Hyperbase', value: '7' },
        { label: 'Impala', value: '8' },
        { label: 'DB2', value: '9' },
        { label: 'SQLServer', value: '10' },
        { label: 'Hive', value: '11' },
        { label: 'KunDB', value: '12' },
        { label: '达梦', value: '13' },
        { label: 'HANA', value: '14' },
        { label: 'Postgres', value: '15' },
        { label: 'FTP', value: '16' },
        { label: 'SFTP', value: '17' },
        { label: 'Kingbase', value: '18' },
        { label: 'Gbase', value: '19' },
        { label: 'Greenplum', value: '20' },
        { label: 'Trino', value: '21' },
        { label: 'MongoDB', value: '22' },
        { label: 'OceanBase', value: '23' },
        { label: 'AS400', value: '23' },
        { label: '自定义', value: '24' },
        { label: 'Kafka', value: '25' },
        { label: 'Clickhouse', value: '26' },
        { label: 'S3', value: '27' },
        { label: 'Timelyre', value: '28' },
      ],
      defaultValue: '0',
    },
  },
  {
    field: 'dataSourceName',
    label: '名称',
    component: 'Input',
    required: true,
  },
  {
    field: 'dataSourceDescription',
    label: '描述',
    component: 'InputTextArea',
    required: false,
  },
  {
    field: 'divider-basic',
    component: 'Divider',
    label: '连接信息',
    colProps: {
      span: 24,
    },
  },
  {
    field: 'collectionType',
    label: '连接',
    component: 'Select',
    required: true,
    componentProps: {
      options: [
        { label: 'Inceptor', value: '0' },
        { label: 'hive', value: '1' },
        { label: 'mysql', value: '2' },
        { label: 'postgresql', value: '3' },
        { label: 'oracle', value: '4' },
        { label: 'sqlserver', value: '5' },
        { label: 'sqlite', value: '6' },
        { label: 'mongodb', value: '7' },
        { label: 'redis', value: '8' },
        { label: 'elasticsearch', value: '9' },
        { label: 'cassandra', value: '10' },
        { label: 'derby', value: '11' },
        { label: 'cockroachdb', value: '12' },
        { label: 'neo4j', value: '13' },
      ],
      defaultValue: '0',
    },
  },
  {
    field: 'defaultConnect',
    label: '默认连接库',
    component: 'Input',
    required: false,
  },
  {
    field: 'connectParams',
    label: '连接参数',
    component: 'Input',
    required: false,
  },
  {
    field: 'authMode',
    label: '认证模式',
    component: 'Select',
    required: true,
    componentProps: {
      options: [
        { label: 'None', value: 'None' },
        { label: 'Kerberos', value: 'Kerberos' },
        { label: 'LDAP', value: 'LDAP' },
        { label: 'Access Token', value: 'AccessToken' },
        { label: 'Password', value: 'Password' },
      ],
      defaultValue: 'None',
    },
  },
  {
    field: 'authMode',
    label: '认证模式',
    component: 'Select',
    required: true,
    componentProps: {
      options: [
        { label: 'None', value: 'None' },
        { label: 'Kerberos', value: 'Kerberos' },
        { label: 'LDAP', value: 'LDAP' },
        { label: 'Access Token', value: 'AccessToken' },
        { label: 'Password', value: 'Password' },
      ],
      defaultValue: 'None',
    },
  },
  {
    field: 'username',
    label: '用户名',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入用户名',
    },
    ifShow: ({ model }) => model.authMode === 'Password' || model.authMode === 'LDAP',
  },
  {
    field: 'password',
    label: '密码',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入密码',
    },
    ifShow: ({ model }) => model.authMode === 'Password' || model.authMode === 'LDAP',
  },
  {
    field: 'principal',
    label: 'principal',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入principal',
    },
    ifShow: ({ model }) => model.authMode === 'Kerberos',
  },
  {
    field: 'KUser',
    label: 'KUser',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入KUser',
    },
    ifShow: ({ model }) => model.authMode === 'Kerberos',
  },
  {
    field: 'KrbHostFQDN',
    label: 'KrbHostFQDN',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: 'Kdc主机域名',
    },
    ifShow: ({ model }) => model.authMode === 'Kerberos',
  },
  {
    field: 'KrbRealm',
    label: 'KrbRealm',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: 'Kerberos安全领域',
    },
    ifShow: ({ model }) => model.authMode === 'Kerberos',
  },
  {
    field: 'KrbServiceName',
    label: 'KrbServiceName',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入KrbServiceName',
    },
    ifShow: ({ model }) => model.authMode === 'Kerberos',
  },
  {
    field: 'Keytab',
    label: 'Keytab',
    component: 'Upload',
    rules: [{ required: true, message: '请选择上传文件' }],
    componentProps: {
      api: uploadApi,
    },
    ifShow: ({ model }) => model.authMode === 'Kerberos',
  },
  {
    field: 'krb5',
    label: 'krb5',
    component: 'Upload',
    rules: [{ required: true, message: '请选择上传文件' }],
    componentProps: {
      api: uploadApi,
    },
    ifShow: ({ model }) => model.authMode === 'Kerberos',
  },
  {
    field: 'AccessToken',
    label: 'AccessToken',
    component: 'Input',
    required: true,
    componentProps: {
      placeholder: '请输入AccessToken',
    },
    ifShow: ({ model }) => model.authMode === 'AccessToken',
  },
  {
    field: 'hdfsMap',
    label: 'HDFS映射',
    component: 'Select',
    required: true,
    componentProps: {
      options: [
        {
          label: 'hive',
          value: 'hive',
        },
      ],
    },
  },
  {
    field: 'divider-basic',
    component: 'Divider',
    label: '元数据管理',
    colProps: {
      span: 24,
    },
  },
  {
    field: 'flag',
    label: '是否在元数据管理展示',
    component: 'RadioGroup',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '是', value: '0' },
        { label: '否', value: '1' },
      ],
    },
    labelWidth: 180,
    required: true,
  },
  {
    field: 'approvalBy',
    component: 'Select',
    label: '数据库',
    componentProps: {
      mode: 'multiple',
      options: [
        { label: 'test1', value: '1' },
        { label: 'test2', value: '2' },
        { label: 'test3', value: '3' },
        { label: 'test4', value: '4' },
        { label: 'test5', value: '5' },
        { label: 'test6', value: '6' },
      ],
    },
    required: true,
  },
  {
    field: 'divider-basic',
    component: 'Divider',
    label: '权限',
    colProps: {
      span: 24,
    },
  },
  {
    field: 'system',
    component: 'Select',
    label: '权属工作组',
    componentProps: {
      options: [
        { label: '人事工作组', value: '人事工作组' },
        { label: '考勤工作组', value: '考勤工作组' },
        { label: '薪资工作组', value: '薪资工作组' },
        { label: '订单工作组', value: '订单工作组' },
      ],
    },
    required: true,
  },
  {
    field: 'see',
    component: 'Select',
    label: '可见范围',
    componentProps: {
      options: [
        { label: '人事工作组', value: '人事工作组' },
        { label: '考勤工作组', value: '考勤工作组' },
        { label: '薪资工作组', value: '薪资工作组' },
        { label: '订单工作组', value: '订单工作组' },
      ],
    },
    required: true,
  },
  {
    field: 'role',
    component: 'Select',
    label: '角色权限',
    componentProps: {
      options: [{ label: '数据源', value: '数据源' }],
    },
    required: true,
  },
];
export const restColumns: BasicColumn[] = [
  {
    title: '数据源名称',
    dataIndex: 'dataSourceName',
    width: 150,
  },
  {
    title: '替换数据源ID',
    dataIndex: 'dataSourceID',
    width: 150,
    edit: true,
  },
];
export const pageConfigFormSchema: FormSchema[] = [
  {
    field: 'flag',
    label: '映射策略',
    component: 'RadioGroup',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      options: [
        { label: '全部生效', value: '0' },
        { label: '数据库生效', value: '1' },
      ],
    },
    required: true,
  },
];
export const pageConfigColumns: BasicColumn[] = [
  {
    title: '分层名称',
    dataIndex: 'pageConfigName',
    width: 150,
  },
  {
    title: '分层英文名称',
    dataIndex: 'name',
    width: 150,
  },
  {
    title: '映射规则',
    dataIndex: 'rule',
    width: 150,
    edit: true,
  },
];
export const dataWarehouseFormSchema: FormSchema[] = [
  {
    field: 'dataSourceName',
    component: 'Input',
    componentProps: {
      placeholder: '输入数据库名称',
    },
    colProps: { span: 4 },
  },
  {
    field: 'pageName',
    component: 'Select',
    componentProps: {
      options: [
        { label: 'DQC', value: 'DQC' },
        { label: 'DW', value: 'DW' },
        { label: 'DM', value: 'DM' },
        { label: 'DST', value: 'DST' },
        { label: 'SRC', value: 'SRC' },
      ],
      placeholder: '选择分层',
    },
    colProps: { span: 4 },
  },
  {
    field: 'system',
    component: 'Select',
    componentProps: {
      options: [
        { label: '人事系统', value: '人事系统' },
        { label: '考勤系统', value: '考勤系统' },
        { label: '薪资系统', value: '薪资系统' },
        { label: '订单系统', value: '订单系统' },
      ],
      placeholder: '选择系统',
    },
    colProps: { span: 4 },
  },
];
export const dataWarehouseColumns: BasicColumn[] = [
  {
    title: '数据库',
    dataIndex: 'dataSourceName',
    width: 150,
  },
  {
    title: '分层名称',
    dataIndex: 'pageName',
    width: 150,
    edit: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        { label: 'DQC', value: 'DQC' },
        { label: 'DW', value: 'DW' },
        { label: 'DM', value: 'DM' },
        { label: 'DST', value: 'DST' },
        { label: 'SRC', value: 'SRC' },
      ],
    },
  },
  {
    title: '所属系统',
    dataIndex: 'system',
    width: 150,
    edit: true,
    editComponent: 'Select',
    editComponentProps: {
      options: [
        { label: '人事系统', value: '人事系统' },
        { label: '考勤系统', value: '考勤系统' },
        { label: '薪资系统', value: '薪资系统' },
        { label: '订单系统', value: '订单系统' },
      ],
    },
  },
];
