import {BasicColumn, FormSchema} from "@/components/Table";
import {uploadApi} from "@/api/sys/upload";

// 表头参数
export const columns: BasicColumn[any] = [
  {
    title: '驱动类型',
    dataIndex: 'driveType',
    width: 150,
  },
  {
    title: '驱动版本',
    dataIndex: 'driveVersion',
    width: 150,
  },
  {
    title: '驱动类名',
    dataIndex: 'driveClass',
    width: 150,
  },
  {
    title: '驱动文件',
    dataIndex: 'driveFile',
    width: 150,
  },
]

// 表头参数
export const searchSchema: BasicColumn[any] = [
  {
    field: 'driveType',
    component: 'Input',
    componentProps: {
      placeholder: '输入驱动类型',
    },
    colProps: {span: 7},
  },
]

// 表单
export const formSchema: FormSchema[] = [
  {
    field: 'driveType',
    label: '驱动类型',
    component: 'Select',
    required: true,
    componentProps: {
      options: [
        { label: 'Inceptor', value: '0' },
        { label: 'Teradata', value: '1' },
        { label: 'ArgoDB', value: '2' },
        { label: 'Mysql', value: '3' },
        { label: 'Oracle', value: '4' },
        { label: 'HDFS', value: '5' },
        { label: 'Hbase', value: '6' },
        { label: 'Hyperbase', value: '7' },
        { label: 'Impala', value: '8' },
        { label: 'DB2', value: '9' },
        { label: 'SQLServer', value: '10' },
        { label: 'Hive', value: '11' },
        { label: 'KunDB', value: '12' },
        { label: '达梦', value: '13' },
        { label: 'HANA', value: '14' },
        { label: 'Postgres', value: '15' },
        { label: 'FTP', value: '16' },
        { label: 'SFTP', value: '17' },
        { label: 'Kingbase', value: '18' },
        { label: 'Gbase', value: '19' },
        { label: 'Greenplum', value: '20' },
        { label: 'Trino', value: '21' },
        { label: 'MongoDB', value: '22' },
        { label: 'OceanBase', value: '23' },
        { label: 'AS400', value: '23' },
        { label: '自定义', value: '24' },
        { label: 'Kafka', value: '25' },
        { label: 'Clickhouse', value: '26' },
        { label: 'S3', value: '27' },
        { label: 'Timelyre', value: '28' },
      ],
      defaultValue: '0',
    },
  },
  {
    field: 'driveVersion',
    label: '驱动版本',
    component: 'Input',
    required: true,
  },
  {
    field: 'driveClass',
    label: '驱动类名',
    component: 'Input',
    required: true,
  },
  {
    field: 'driveFile',
    label: '驱动文件',
    component: 'Input',
    required: false,
  },
]

// 添加/修改驱动 表头
export const driveFormSchema: FormSchema[any] = [
  {
    field: 'driveType',
    label: '驱动类型',
    component: 'Select',
    required: true,
    labelWidth: 150,
    componentProps: {
      options: [
        { label: 'Inceptor', value: 'Inceptor' },
        { label: 'mysql', value: 'mysql' },
        { label: 'hive', value: 'hive' },
        { label: 'oracle', value: 'oracle' },
        { label: 'sqlserver', value: 'sqlserver' },
      ]
    }
  },
  {
    field: 'driveVersion',
    label: '驱动版本',
    component: 'Input',
    required: true,
    labelWidth: 150,
  },
  {
    field: 'driveClass',
    label: '驱动类名',
    component: 'Input',
    required: true,
    labelWidth: 150,
  },
  {
    field: 'driveFile',
    component: 'Upload',
    label: '驱动文件',
    rules: [{ required: false, message: '请选择上传文件' }],
    componentProps: {
      api: uploadApi,
    },
    labelWidth: 150,
  },
]
